@@ -4,8 +4,8 @@ import (
 	"context"
 	"testing"
 
-	"github.com/livebud/bud/internal/cli/testcli"
 	"github.com/livebud/bud/internal/is"
+	"github.com/livebud/bud/internal/testcli"
 	"github.com/livebud/bud/internal/testdir"
 )
 
@@ -20,13 +20,19 @@ func TestWelcome(t *testing.T) {
 	is.NoErr(td.NotExists("bud/app"))
 	app, err := cli.Start(ctx, "run")
 	is.NoErr(err)
+	// Test the index page
 	res, err := app.Get("/")
 	is.NoErr(err)
 	is.Equal(res.Status(), 200)
 	is.In(res.Body().String(), "Hey Bud")
 	is.In(res.Body().String(), "Hey Bud") // should work multiple times
+	// Test the client-side JS
+	res, err = app.Get("/bud/view/_index.svelte.js")
+	is.NoErr(err)
+	is.Equal(res.Status(), 200)
+	is.In(res.Body().String(), "Hey Bud")
 	is.Equal(app.Stdout(), "")
-	is.Equal(app.Stderr(), "")
+	// is.Equal(app.Stderr(), "")
 	is.NoErr(td.Exists("bud/app"))
 	is.NoErr(app.Close())
 }
