@@ -4,7 +4,7 @@ import (
 	_ "embed"
 
 	"github.com/livebud/bud/framework"
-	"github.com/livebud/bud/package/budfs"
+	"github.com/livebud/bud/package/genfs"
 	"github.com/livebud/bud/package/gomod"
 
 	"github.com/livebud/bud/internal/gotemplate"
@@ -33,7 +33,7 @@ type Generator struct {
 	module *gomod.Module
 }
 
-func (g *Generator) GenerateFile(fsys budfs.FS, file *budfs.File) error {
+func (g *Generator) GenerateFile(fsys genfs.FS, file *genfs.File) error {
 	state, err := Load(fsys, g.flag)
 	if err != nil {
 		return err
