@@ -5,8 +5,10 @@ import (
 	"io/fs"
 	"path/filepath"
 	"strconv"
+	"time"
 
 	"github.com/livebud/bud/internal/dsync/set"
+	"github.com/livebud/bud/package/log"
 	"github.com/livebud/bud/package/vfs"
 )
 
@@ -14,6 +16,7 @@ type skipFunc = func(name string, isDir bool) bool
 
 type option struct {
 	Skip skipFunc
+	log  log.Log
 	rel  func(spath string) (string, error)
 }
 
@@ -30,6 +33,12 @@ func WithSkip(skips ...skipFunc) Option {
 	}
 }
 
+func WithLog(log log.Log) Option {
+	return func(o *option) {
+		o.log = log
+	}
+}
+
 func composeSkips(skips []skipFunc) skipFunc {
 	return func(name string, isDir bool) bool {
 		for _, skip := range skips {
@@ -56,22 +65,27 @@ func Rel(sdir, tdir string) func(path string) (string, error) {
 func Dir(sfs fs.FS, sdir string, tfs vfs.ReadWritable, tdir string, options ...Option) error {
 	opt := &option{
 		Skip: func(name string, isDir bool) bool { return false },
+		log:  log.Discard,
 		rel:  Rel(sdir, tdir),
 	}
 	for _, option := range options {
 		option(opt)
 	}
+	opt.log = opt.log.Field("package", "dsync")
+	opt.log.Debug("syncing")
+	now := time.Now()
 	ops, err := diff(opt, sfs, sdir, tfs, tdir)
 	if err != nil {
 		return err
 	}
-	err = apply(sfs, tfs, ops)
+	err = apply(opt, sfs, tfs, ops)
+	opt.log.Field("duration", time.Since(now)).Debug("synced")
 	return err
 }
 
 // To syncs the "to" directory from the source to target filesystem
-func To(sfs fs.FS, tfs vfs.ReadWritable, to string) error {
-	return Dir(sfs, to, tfs, to)
+func To(sfs fs.FS, tfs vfs.ReadWritable, to string, options ...Option) error {
+	return Dir(sfs, to, tfs, to, options...)
 }
 
 type OpType uint8
@@ -106,6 +120,7 @@ func (o Op) String() string {
 }
 
 func diff(opt *option, sfs fs.FS, sdir string, tfs vfs.ReadWritable, tdir string) (ops []Op, err error) {
+	log := opt.log.Field("fn", "diff")
 	sourceEntries, err := fs.ReadDir(sfs, sdir)
 	if err != nil {
 		return nil, err
@@ -114,8 +129,11 @@ func diff(opt *option, sfs fs.FS, sdir string, tfs vfs.ReadWritable, tdir string
 	if err != nil && !errors.Is(err, fs.ErrNotExist) {
 		return nil, err
 	}
+	// Create the source set from the source entries
 	sourceSet := set.New(sourceEntries...)
+	// Create a target set from the target entries
 	targetSet := set.New(targetEntries...)
+	// Compute the operations
 	creates := set.Difference(sourceSet, targetSet)
 	deletes := set.Difference(targetSet, sourceSet)
 	updates := set.Intersection(sourceSet, targetSet)
@@ -134,6 +152,9 @@ func diff(opt *option, sfs fs.FS, sdir string, tfs vfs.ReadWritable, tdir string
 	ops = append(ops, createOps...)
 	ops = append(ops, deleteOps...)
 	ops = append(ops, childOps...)
+	for _, op := range ops {
+		log.Debug("op: %s %q", op.Type, op.Path)
+	}
 	return ops, nil
 }
 
@@ -164,6 +185,10 @@ func createOps(opt *option, sfs fs.FS, dir string, des []fs.DirEntry) (ops []Op,
 		}
 		des, err := fs.ReadDir(sfs, path)
 		if err != nil {
+			// Ignore ReadDir that fail when the path doesn't exist
+			if errors.Is(err, fs.ErrNotExist) {
+				continue
+			}
 			return nil, err
 		}
 		createOps, err := createOps(opt, sfs, path, des)
@@ -227,27 +252,31 @@ func updateOps(opt *option, sfs fs.FS, sdir string, tfs vfs.ReadWritable, tdir s
 		if sourceStamp == targetStamp {
 			continue
 		}
+		rel, err := opt.rel(spath)
+		if err != nil {
+			return nil, err
+		}
 		data, err := fs.ReadFile(sfs, spath)
 		if err != nil {
 			// Don't error out on files that don't exist
 			if errors.Is(err, fs.ErrNotExist) {
+				// The file no longer exists, delete it
+				ops = append(ops, Op{DeleteType, rel, nil})
 				continue
 			}
 			return nil, err
 		}
-		rel, err := opt.rel(spath)
-		if err != nil {
-			return nil, err
-		}
 		ops = append(ops, Op{UpdateType, rel, data})
 	}
 	return ops, nil
 }
 
-func apply(sfs fs.FS, tfs vfs.ReadWritable, ops []Op) error {
+func apply(opt *option, sfs fs.FS, tfs vfs.ReadWritable, ops []Op) error {
+	log := opt.log.Field("fn", "apply")
 	for _, op := range ops {
 		switch op.Type {
 		case CreateType:
+			log.Debug("creating %q", op.Path)
 			dir := filepath.Dir(op.Path)
 			if err := tfs.MkdirAll(dir, 0755); err != nil {
 				return err
@@ -256,10 +285,12 @@ func apply(sfs fs.FS, tfs vfs.ReadWritable, ops []Op) error {
 				return err
 			}
 		case UpdateType:
+			log.Debug("updating %q", op.Path)
 			if err := tfs.WriteFile(op.Path, op.Data, 0644); err != nil {
 				return err
 			}
 		case DeleteType:
+			log.Debug("removing %q", op.Path)
 			if err := tfs.RemoveAll(op.Path); err != nil {
 				return err
 			}
