@@ -1805,7 +1805,7 @@ func TestStructMapNeedsPointer(t *testing.T) {
 	})
 }
 
-func TestFunctionMapNeedsPointer(t *testing.T) {
+func TestFunctionAliasToStruct(t *testing.T) {
 	runTest(t, Test{
 		Function: &di.Function{
 			Name:   "Load",
@@ -1862,6 +1862,88 @@ func TestFunctionMapNeedsPointer(t *testing.T) {
 	})
 }
 
+func TestFunctionInterfaceParam(t *testing.T) {
+	runTest(t, Test{
+		Function: &di.Function{
+			Name:   "Load",
+			Target: "app.com/gen/web",
+			Params: []*di.Param{
+				&di.Param{
+					Import: "app.com/js/v8",
+					Type:   "V8",
+				},
+			},
+			Results: []di.Dependency{
+				di.ToType("app.com/web", "*Web"),
+			},
+			Aliases: di.Aliases{
+				di.ToType("app.com/js", "VM"): di.ToType("app.com/js/v8", "V8"),
+			},
+		},
+		Expect: `
+			&web.Web{VM: &v8.v8{}}
+		`,
+		Files: map[string]string{
+			"go.mod": goMod,
+			"main.go": `package main
+
+				import (
+					"os"
+					"fmt"
+					"github.com/hexops/valast"
+					"app.com/gen/web"
+					"app.com/js/v8"
+				)
+
+				func main() {
+					v8 := v8.New()
+					actual := web.Load(v8)
+					fmt.Fprintf(os.Stdout, "%s\n", valast.String(actual))
+				}
+			`,
+			"web/web.go": `
+				package web
+
+				import (
+					"app.com/js"
+				)
+
+				func New(vm js.VM) *Web {
+					return &Web{vm}
+				}
+
+				type Web struct {
+					VM js.VM
+				}
+			`,
+			"js/js.go": `
+				package js
+
+				type VM interface {
+					Eval(input string) (string, error)
+				}
+			`,
+			"js/v8/v8.go": `
+				package v8
+
+				func New() V8 {
+					return &v8{}
+				}
+
+				type V8 interface {
+					Eval(input string) (string, error)
+				}
+
+				type v8 struct {}
+
+				func (v *v8) Eval(input string) (string, error) {
+					return "", nil
+				}
+			`,
+		},
+	})
+}
+
 func TestInputStruct(t *testing.T) {
 	runTest(t, Test{
 		Function: &di.Function{
@@ -2333,6 +2415,106 @@ func TestHoistable(t *testing.T) {
 	})
 }
 
+func TestV8Alias(t *testing.T) {
+	runTest(t, Test{
+		Function: &di.Function{
+			Name:   "Load",
+			Target: "app.com/gen/web",
+			Params: []*di.Param{},
+			Results: []di.Dependency{
+				di.ToType("app.com/web", "*Controller"),
+				&di.Error{},
+			},
+			Aliases: di.Aliases{
+				di.ToType("app.com/js", "VM"): di.ToType("app.com/js/v8", "*VM"),
+			},
+		},
+		Expect: `
+			&web.Controller{VM: &js.VM{}}
+		`,
+		Files: map[string]string{
+			"go.mod":  goMod,
+			"main.go": mainGoWithErr,
+			"js/vm.go": `
+				package js
+				type VM interface {
+					Eval(expr string) (string, error)
+				}
+			`,
+			"js/v8/v8.go": `
+				package js
+				func Load() (*VM, error) {
+					return &VM{}, nil
+				}
+				type VM struct {}
+				func (v *VM) Eval(expr string) (string, error) {
+					return "v8", nil
+				}
+			`,
+			"web/web.go": `
+				package web
+				import "app.com/js"
+				func Load(vm js.VM) *Controller {
+					return &Controller{vm}
+				}
+				type Controller struct {
+					VM js.VM
+				}
+			`,
+		},
+	})
+}
+
+func TestAliasBack(t *testing.T) {
+	runTest(t, Test{
+		Function: &di.Function{
+			Name:   "Load",
+			Target: "app.com/gen/web",
+			Params: []*di.Param{},
+			Results: []di.Dependency{
+				di.ToType("app.com/web", "*Controller"),
+				&di.Error{},
+			},
+			Aliases: di.Aliases{
+				di.ToType("app.com/log", "Log"): di.ToType("app.com/log/console", "Log"),
+			},
+		},
+		Expect: `
+			&web.Controller{log: &console.console{}}
+		`,
+		Files: map[string]string{
+			"go.mod":  goMod,
+			"main.go": mainGoWithErr,
+			"log/log.go": `
+				package log
+				type Log interface {
+					Log(msg string)
+				}
+			`,
+			"log/console/console.go": `
+				package console
+				import "app.com/log"
+				func Load() (Log, error) {
+					return &console{}, nil
+				}
+				type console struct{}
+				func (c *console) Log(msg string) {}
+				type Log = log.Log
+			`,
+			"web/web.go": `
+				package web
+				import "app.com/log"
+				func Load(log log.Log) *Controller {
+					return &Controller{log}
+				}
+				type Controller struct {
+					log log.Log
+				}
+			`,
+		},
+	})
+}
+
 // TODO: figure out how to test imports as inputs
 
 // IDEA: consider renaming Target to Import
