@@ -297,3 +297,21 @@ func TestFindBy(t *testing.T) {
 	is.Equal(modules[0].Import(), "github.com/livebud/bud-test-nested-plugin")
 	is.Equal(modules[1].Import(), "github.com/livebud/bud-test-plugin")
 }
+
+func TestNew(t *testing.T) {
+	is := is.New(t)
+	dir, err := filepath.EvalSymlinks(t.TempDir())
+	is.NoErr(err)
+	module := gomod.New(dir)
+	is.Equal(dir, module.Directory())
+	is.Equal(module.Import(), "change.me")
+}
+
+func TestDeleteOutside(t *testing.T) {
+	is := is.New(t)
+	dir := t.TempDir()
+	is.NoErr(os.MkdirAll(filepath.Join(dir, "livebud", "bud"), 0755))
+	module := gomod.New(filepath.Join(dir, "livebud", "bud"))
+	err := module.RemoveAll("../..")
+	is.True(errors.Is(err, fs.ErrInvalid))
+}
