@@ -1,15 +1,12 @@
 package log
 
 import (
-	"flag"
 	"fmt"
 )
 
 // Level of the logger
 type Level uint8
 
-var _ flag.Value = (*Level)(nil)
-
 // Log level
 const (
 	DebugLevel Level = iota + 1
@@ -36,15 +33,6 @@ func (level Level) String() string {
 	}
 }
 
-func (level *Level) Set(l string) error {
-	lvl, err := ParseLevel(l)
-	if err != nil {
-		return err
-	}
-	*level = lvl
-	return nil
-}
-
 func ParseLevel(level string) (Level, error) {
 	switch level {
 	case "debug":
